@@ -307,7 +307,7 @@ armor_encode (void * opaque, FILE * in, FILE * out)
   fprintf (out, "%s", lf);
 
   if (fstat (fileno (in), &statbuf))
-      return CDK_General_Error;
+    return CDK_General_Error;
 
   while (!feof (in))
     {
@@ -334,7 +334,7 @@ armor_encode (void * opaque, FILE * in, FILE * out)
   fprintf (out, "=%s%s", crcbuf, lf);
   fprintf (out, "-----%s-----%s", armor_end[afx->idx2], lf);
 
-leave:
+ leave:
   return rc;
 }
 
@@ -414,7 +414,7 @@ armor_decode (void * opaque, FILE *in, FILE *out)
       s = fgets (buf, sizeof buf-1, in);
       if (!s)
         goto leave;
-      if (strlen (s) == 1)
+      if (strlen (s) == strlen (LF))
 	{
 	  rc = 0;
 	  break; /* empty line */
@@ -491,6 +491,13 @@ leave:
 }
 
 
+/**
+ * cdk_file_armor: Protect a file with ASCII armor.
+ * @hd: Handle
+ * @file: Name of the file to protect.
+ * @output: Output filename.
+ *
+ **/
 int
 cdk_file_armor (CDK_HD hd, const char *file, const char *output)
 {
@@ -525,6 +532,12 @@ cdk_file_armor (CDK_HD hd, const char *file, const char *output)
 }
 
 
+/**
+ * cdk_file_dearmor: Remove ASCII armor from a file.
+ * @file: Name of the file to unprotect.
+ * @output: Output filename.
+ *
+ **/
 int
 cdk_file_dearmor (const char *file, const char *output)
 {
