@@ -1100,7 +1100,8 @@ cdk_keydb_export (CDK_STREAM out, CDK_STRLIST remusr, int secret)
 	  /* we never export local signed signatures */
 	  if (node->pkt->pkttype == CDK_PKT_SIGNATURE &&
 	      !node->pkt->pkt.signature->flags.exportable)
-	    continue;
+            continue;
+
 	  rc = cdk_pkt_build (out, node->pkt);
 	  if (rc)
 	    break;
@@ -1113,6 +1114,56 @@ cdk_keydb_export (CDK_STREAM out, CDK_STRLIST remusr, int secret)
 }
 
 
+int
+cdk_keydb_import (CDK_KEYDB_HD hd, CDK_KBNODE knode)
+{
+  CDK_KBNODE node, chk = NULL;
+  CDK_PACKET * pkt;
+  CDK_STREAM inp;
+  u32 keyid[2];
+  size_t len;
+  int rc = 0;
+
+  pkt = cdk_kbnode_find_packet (knode, CDK_PKT_PUBLIC_KEY);
+  if (!pkt)
+      return CDK_Inv_Packet;
+  cdk_pk_get_keyid (pkt->pkt.public_key, keyid);
+  cdk_keydb_get_bykeyid (hd, keyid, &chk);
+  if (chk)
+    {
+      cdk_kbnode_release (chk);
+      return 0;
+    }
+  
+  cdk_keydb_search_reset (hd);
+  inp = hd->buf;
+  if (!inp)
+    {
+      rc = cdk_stream_open (hd->name, &inp);
+      if (rc)
+        return rc;
+    }
+  
+  len = cdk_stream_get_length (inp);
+  if (len > 0)
+    cdk_stream_seek (inp, len);
+  
+  for (node = knode; node; node = node->next)
+    {
+      if (node->pkt->pkttype == CDK_PKT_RING_TRUST)
+        continue; /* No uniformed syntax for this packet */
+      rc = cdk_pkt_build (inp, node->pkt);
+      if (rc)
+        break;
+    }
+  
+  if (!hd->buf)
+    cdk_stream_close (inp);
+
+  return rc;
+}  
+
+
 /* internal functions */
 CDK_KBNODE
 _cdk_keydb_get_pkblock (u32 * keyid)
@@ -1127,6 +1178,7 @@ _cdk_keydb_get_pkblock (u32 * keyid)
       rc = cdk_keydb_get_bykeyid (hd, keyid, &kbnode);
       if (rc)
         kbnode = NULL;
+      cdk_keydb_search_reset (hd);
     }
   return kbnode;
 }
