@@ -23,14 +23,14 @@
 
 #include <gcrypt.h>
 
-#define OPENCDK_VERSION "0.3.1"
+#define OPENCDK_VERSION "0.3.2"
 
 /* General contexts */
 struct cdk_handle_s;
 typedef struct cdk_handle_s *CDK_HD;
 
-struct cdk_string_list;
-typedef struct cdk_string_list *CDK_STRLIST;
+struct cdk_string_list_s;
+typedef struct cdk_string_list_s *CDK_STRLIST;
 
 struct cdk_mpi_s;
 typedef struct cdk_mpi_s *CDK_MPI;
@@ -211,7 +211,7 @@ typedef struct
   unsigned is_revoked:1;
   unsigned mdc_feature:1;
   CDK_PREFITEM prefs;
-  unsigned char *attrib_img; /* TAG 17 if not null */
+  unsigned char * attrib_img; /* TAG 17 if not null */
   size_t attrib_len;
   size_t prefs_size;
   unsigned long created;
@@ -232,7 +232,7 @@ typedef struct
   unsigned is_invalid:1;
   unsigned has_expired:1;
   int pubkey_usage;
-  cdkPKT_user_id *uid;
+  cdkPKT_user_id * uid;
   CDK_PREFITEM prefs;
   size_t prefs_size;
 } cdkPKT_public_key;
@@ -240,7 +240,7 @@ typedef struct
 
 typedef struct
 {
-  cdkPKT_public_key *pk;
+  cdkPKT_public_key * pk;
   unsigned short expiredate;
   int version;
   int pubkey_algo;
@@ -257,7 +257,7 @@ typedef struct
   } protect;
   unsigned short csum;
   CDK_MPI mpi[4];
-  unsigned char *encdata;
+  unsigned char * encdata;
   size_t enclen;
   unsigned char is_protected;
   unsigned is_primary:1;
@@ -370,17 +370,17 @@ struct cdk_packet_s
   cdk_packet_types_t pkttype;
   union
   {
-    cdkPKT_mdc *mdc;
-    cdkPKT_user_id *user_id;
-    cdkPKT_public_key *public_key;
-    cdkPKT_secret_key *secret_key;
-    cdkPKT_signature *signature;
-    cdkPKT_pubkey_enc *pubkey_enc;
-    cdkPKT_symkey_enc *symkey_enc;
-    cdkPKT_compressed *compressed;
-    cdkPKT_encrypted *encrypted;
-    cdkPKT_plaintext *plaintext;
-    cdkPKT_onepass_sig *onepass_sig;
+    cdkPKT_mdc * mdc;
+    cdkPKT_user_id * user_id;
+    cdkPKT_public_key * public_key;
+    cdkPKT_secret_key * secret_key;
+    cdkPKT_signature * signature;
+    cdkPKT_pubkey_enc * pubkey_enc;
+    cdkPKT_symkey_enc * symkey_enc;
+    cdkPKT_compressed * compressed;
+    cdkPKT_encrypted * encrypted;
+    cdkPKT_plaintext * plaintext;
+    cdkPKT_onepass_sig * onepass_sig;
   } pkt;
 };
 typedef struct cdk_packet_s CDK_PACKET;
@@ -389,23 +389,23 @@ typedef struct cdk_packet_s CDK_PACKET;
 /*-- main.c --*/
 typedef void (*CDK_LOG_FNC) (void *, int, const char *, va_list);
 void cdk_set_log_level (int lvl);
-void cdk_set_log_handler (CDK_LOG_FNC logfnc, void *opaque);
+void cdk_set_log_handler (CDK_LOG_FNC logfnc, void * opaque);
 const char* cdk_strerror (int ec);
 void cdk_set_malloc_hooks (void *(*new_alloc_func) (size_t n),
                            void *(*new_alloc_secure_func) (size_t n),
-                           void *(*new_realloc_func) (void *p, size_t n),
+                           void *(*new_realloc_func) (void * p, size_t n),
                            void *(*new_calloc_func) (size_t m, size_t n),
                            void (*new_free_func) (void *));
 int cdk_malloc_hook_initialized (void);
-void *cdk_malloc (size_t size);
-void *cdk_calloc (size_t n, size_t m);
-void *cdk_realloc (void *ptr, size_t size);
-void *cdk_salloc (size_t size);
-void *cdk_scalloc (size_t m);
-void *cdk_strdup (const char *ptr);
-void cdk_free (void *ptr);
+void * cdk_malloc (size_t size);
+void * cdk_calloc (size_t n, size_t m);
+void * cdk_realloc (void * ptr, size_t size);
+void * cdk_salloc (size_t size);
+void * cdk_scalloc (size_t m);
+void * cdk_strdup (const char * ptr);
+void cdk_free (void * ptr);
 
-int cdk_handle_new (CDK_HD *r_ctx);
+int cdk_handle_new (CDK_HD * r_ctx);
 void cdk_handle_free (CDK_HD c);
 void cdk_handle_set_s2k (CDK_HD hd, int mode, int digest, int cipher);
 void cdk_handle_set_cipher (CDK_HD hd, int cipher);
@@ -413,12 +413,12 @@ void cdk_handle_set_digest (CDK_HD hd, int digest);
 void cdk_handle_set_compress (CDK_HD hd, int algo);
      
 /*-- new-packet.c --*/
-int cdk_pkt_new (CDK_PACKET **r_pkt);
-int cdk_pkt_alloc (CDK_PACKET **r_pkt, int id);
-void cdk_pkt_free (CDK_PACKET *pkt);
-void cdk_pkt_release (CDK_PACKET *pkt);
-int cdk_pkt_parse (CDK_STREAM inp, CDK_PACKET *pkt);
-int cdk_pkt_build (CDK_STREAM out, CDK_PACKET *pkt);
+int cdk_pkt_new (CDK_PACKET ** r_pkt);
+int cdk_pkt_alloc (CDK_PACKET ** r_pkt, int id);
+void cdk_pkt_free (CDK_PACKET * pkt);
+void cdk_pkt_release (CDK_PACKET * pkt);
+int cdk_pkt_parse (CDK_STREAM inp, CDK_PACKET * pkt);
+int cdk_pkt_build (CDK_STREAM out, CDK_PACKET * pkt);
 CDK_SUBPKT cdk_subpkt_new (size_t size);
 void cdk_subpkt_free (CDK_SUBPKT ctx);
 CDK_SUBPKT cdk_subpkt_find (CDK_SUBPKT ctx, int type);
@@ -433,19 +433,19 @@ const unsigned char * cdk_subpkt_get_buf (CDK_SUBPKT ctx,
 #define is_ELG(a) ((a) == GCRY_PK_ELG || (a) == GCRY_PK_ELG_E)
 #define is_DSA(a) ((a) == GCRY_PK_DSA)
 
-int cdk_pk_encrypt (cdkPKT_public_key *pk, cdkPKT_pubkey_enc *pke,
+int cdk_pk_encrypt (cdkPKT_public_key * pk, cdkPKT_pubkey_enc * pke,
                     GCRY_MPI esk);
-int cdk_pk_decrypt (cdkPKT_secret_key *sk, cdkPKT_pubkey_enc *pke,
+int cdk_pk_decrypt (cdkPKT_secret_key * sk, cdkPKT_pubkey_enc * pke,
                     GCRY_MPI *r_sk);
-int cdk_pk_sign (cdkPKT_secret_key *sk, cdkPKT_signature *sig,
-                 const unsigned char *md);
-int cdk_pk_verify (cdkPKT_public_key *pk, cdkPKT_signature *sig,
-                   const unsigned char *md);
+int cdk_pk_sign (cdkPKT_secret_key * sk, cdkPKT_signature * sig,
+                 const unsigned char * md);
+int cdk_pk_verify (cdkPKT_public_key * pk, cdkPKT_signature * sig,
+                   const unsigned char * md);
 int cdk_pk_get_mpi (cdkPKT_public_key * pk, int idx,
                     unsigned char * buf, size_t * r_count, size_t * r_nbits);
 int cdk_sk_get_mpi (cdkPKT_secret_key * sk, int idx,
-                    unsigned char *buf, size_t * r_count, size_t * r_nbits);
-int cdk_pk_get_nbits (cdkPKT_public_key *pk);
+                    unsigned char * buf, size_t * r_count, size_t * r_nbits);
+int cdk_pk_get_nbits (cdkPKT_public_key * pk);
 int cdk_pk_get_npkey (int algo);
 int cdk_pk_get_nskey (int algo);
 int cdk_pk_get_nsig (int algo);
@@ -463,27 +463,27 @@ CDK_DEK cdk_passphrase_to_dek (int cipher_algo, CDK_S2K_HD * s2k,
 void cdk_passphrase_cb_set (CDK_PASSPHRASE_CB pass_fnc);
 
 /*-- seskey.c --*/
-CDK_DEK cdk_pkcs1_to_dek (cdkPKT_pubkey_enc * enc, cdkPKT_secret_key *sk);
+CDK_DEK cdk_pkcs1_to_dek (cdkPKT_pubkey_enc * enc, cdkPKT_secret_key * sk);
 int cdk_dek_new (CDK_DEK * r_dek, int algo);
 
 /*-- armor.c --*/
-int cdk_file_armor (CDK_HD hd, const char *file, const char *output);
-int cdk_file_dearmor (const char *file, const char *output);
+int cdk_file_armor (CDK_HD hd, const char * file, const char * output);
+int cdk_file_dearmor (const char * file, const char *output);
 int cdk_armor_filter_use (CDK_STREAM inp);
 
 /*-- stream.c --*/
 int cdk_stream_control (CDK_STREAM s, int ctl, int val);
-int cdk_stream_open (const char *file, CDK_STREAM *ret_s);
-int cdk_stream_new (const char *file, CDK_STREAM *ret_s);
+int cdk_stream_open (const char * file, CDK_STREAM * ret_s);
+int cdk_stream_new (const char * file, CDK_STREAM * ret_s);
 CDK_STREAM cdk_stream_tmp (void);
 CDK_STREAM cdk_stream_tmp_from_mem (const unsigned char *buf, size_t count);
-CDK_STREAM cdk_stream_fpopen (FILE *fp, unsigned write_mode);
+CDK_STREAM cdk_stream_fpopen (FILE * fp, unsigned write_mode);
 int cdk_stream_set_cache (CDK_STREAM s, int val);
 int cdk_stream_filter_disable (CDK_STREAM s, int type);
 int cdk_stream_close (CDK_STREAM s);
 unsigned cdk_stream_get_length (CDK_STREAM s);
-int cdk_stream_read (CDK_STREAM s, void *buf, size_t count);
-int cdk_stream_write (CDK_STREAM s, const void *buf, size_t count);
+int cdk_stream_read (CDK_STREAM s, void * buf, size_t count);
+int cdk_stream_write (CDK_STREAM s, const void * buf, size_t count);
 int cdk_stream_putc (CDK_STREAM s, int c);
 int cdk_stream_getc (CDK_STREAM s);
 int cdk_stream_eof (CDK_STREAM s);
@@ -500,64 +500,64 @@ int cdk_stream_kick_off (CDK_STREAM inp, CDK_STREAM out);
 /*-- keydb.c --*/
 int cdk_keydb_new (CDK_KEYDB_HD * r_hd, int type,
                    unsigned char * data, size_t count);
-int cdk_keydb_open (CDK_KEYDB_HD kdb, CDK_STREAM *ret_kr);
-int cdk_keydb_add_resource (const char *name, int is_secret);
+int cdk_keydb_open (CDK_KEYDB_HD kdb, CDK_STREAM * ret_kr);
+int cdk_keydb_add_resource (const char * name, int is_secret);
 int cdk_keydb_remove_resource (int id);
 const char* cdk_keydb_get_name (int id);
 int cdk_keydb_is_secret (int id);
-int cdk_keydb_find_idx (int is_secret, int *r_pos);
+int cdk_keydb_find_idx (int is_secret, int * r_pos);
 CDK_KEYDB_HD cdk_keydb_get_ctx (int is_secret, int id);
 int cdk_keydb_search_new (CDK_DBSEARCH * r_dbs, int type, void * desc);
 void cdk_keydb_search_free (CDK_DBSEARCH dbs);
 int cdk_keydb_search (CDK_KEYDB_HD kdb, CDK_DBSEARCH ks, CDK_KBNODE *r_key);
 void cdk_keydb_search_reset (CDK_KEYDB_HD hd);
 int cdk_keydb_get_bykeyid (CDK_KEYDB_HD kdb, unsigned long *keyid,
-                           CDK_KBNODE *r_key);
-int cdk_keydb_get_byfpr (CDK_KEYDB_HD kdb, const unsigned char *fpr,
-                         CDK_KBNODE *r_key);
-int cdk_keydb_get_bypattern (CDK_KEYDB_HD kdb, const char *patt,
-                             CDK_KBNODE *r_pkt);
+                           CDK_KBNODE * r_key);
+int cdk_keydb_get_byfpr (CDK_KEYDB_HD kdb, const unsigned char * fpr,
+                         CDK_KBNODE * r_key);
+int cdk_keydb_get_bypattern (CDK_KEYDB_HD kdb, const char * patt,
+                             CDK_KBNODE * r_pkt);
 int cdk_keydb_get_pk (CDK_KEYDB_HD khd, unsigned long *keyid,
-                      cdkPKT_public_key **ret_pk);
+                      cdkPKT_public_key ** ret_pk);
 int cdk_keydb_get_sk (CDK_KEYDB_HD khd, unsigned long *keyid,
-                      cdkPKT_secret_key **ret_sk);
-int cdk_keydb_get_pk_byname (const char *name, cdkPKT_public_key **ret_pk,
+                      cdkPKT_secret_key ** ret_sk);
+int cdk_keydb_get_pk_byname (const char * name, cdkPKT_public_key **ret_pk,
                              int alloced);
-int cdk_keydb_get_sk_byname (const char *name, cdkPKT_secret_key **ret_sk,
+int cdk_keydb_get_sk_byname (const char * name, cdkPKT_secret_key **ret_sk,
                              int alloced);
-int cdk_keydb_get_keyblock (CDK_STREAM inp, CDK_KBNODE *ret_key);
+int cdk_keydb_get_keyblock (CDK_STREAM inp, CDK_KBNODE * ret_key);
 int cdk_keydb_export (CDK_STREAM out, CDK_STRLIST remusr, int secret);
+int cdk_keydb_import (CDK_KEYDB_HD hd, CDK_KBNODE knode);
 
 /*-- kbnode.c --*/
-CDK_KBNODE cdk_kbnode_new (CDK_PACKET *pkt);
+CDK_KBNODE cdk_kbnode_new (CDK_PACKET * pkt);
 void cdk_kbnode_release (CDK_KBNODE n);
 CDK_KBNODE cdk_kbnode_walk (CDK_KBNODE root, CDK_KBNODE * context, int all);
-CDK_PACKET* cdk_kbnode_find_packet (CDK_KBNODE node, int pkttype);
-CDK_PACKET* cdk_kbnode_get_packet (CDK_KBNODE node);
+CDK_PACKET * cdk_kbnode_find_packet (CDK_KBNODE node, int pkttype);
+CDK_PACKET * cdk_kbnode_get_packet (CDK_KBNODE node);
 CDK_KBNODE cdk_kbnode_find (CDK_KBNODE node, int pkttype);
-CDK_KBNODE cdk_kbnode_find_prev (CDK_KBNODE root, CDK_KBNODE node,
-                                 int pkttype);
+CDK_KBNODE cdk_kbnode_find_prev (CDK_KBNODE root, CDK_KBNODE node, int pkttyp);
 CDK_KBNODE cdk_kbnode_find_next (CDK_KBNODE node, int pkttype);
 
 /*-- keyid.c --*/
-int cdk_pk_get_fingerprint (cdkPKT_public_key *pk, unsigned char *fpr);
-unsigned long cdk_pk_fingerprint_get_keyid (const unsigned char *fpr,
+int cdk_pk_get_fingerprint (cdkPKT_public_key * pk, unsigned char * fpr);
+unsigned long cdk_pk_fingerprint_get_keyid (const unsigned char * fpr,
                                             size_t fprlen,
-                                            unsigned long *keyid);
-unsigned long cdk_pk_get_keyid (cdkPKT_public_key *pk, unsigned long *keyid);
-unsigned long cdk_sk_get_keyid (cdkPKT_secret_key *sk, unsigned long *keyid);
-unsigned long cdk_sig_get_keyid (cdkPKT_signature *sig, unsigned long *keyid);
+                                            unsigned long * keyid);
+unsigned long cdk_pk_get_keyid (cdkPKT_public_key * pk, unsigned long *keyid);
+unsigned long cdk_sk_get_keyid (cdkPKT_secret_key * sk, unsigned long *keyid);
+unsigned long cdk_sig_get_keyid (cdkPKT_signature * sig, unsigned long *keyid);
 
 /*-- sig-check.c --*/
-int cdk_key_check_sigs (CDK_KBNODE kb_pk, CDK_KEYDB_HD khd, int *r_status);
+int cdk_key_check_sigs (CDK_KBNODE kb_pk, CDK_KEYDB_HD khd, int * r_status);
 
 /*-- keylist.c --*/
 int cdk_pklist_select_algo (CDK_KEYLIST pkl);
 int cdk_pklist_use_mdc (CDK_KEYLIST pkl);
-int cdk_pklist_build (CDK_STRLIST remusr, CDK_KEYLIST *ret_pkl, int use);
+int cdk_pklist_build (CDK_STRLIST remusr, CDK_KEYLIST * ret_pkl, int use);
 void cdk_pklist_release (CDK_KEYLIST pkl);
 int cdk_pklist_encrypt (CDK_KEYLIST pkl, CDK_DEK dek, CDK_STREAM out);
-int cdk_sklist_build (CDK_STRLIST locusr, CDK_KEYLIST *ret_skl, int unlock,
+int cdk_sklist_build (CDK_STRLIST locusr, CDK_KEYLIST * ret_skl, int unlock,
                       unsigned int use);
 void cdk_sklist_release (CDK_KEYLIST skl);
 int cdk_sklist_write (CDK_KEYLIST skl, CDK_STREAM outp, GCRY_MD_HD hash,
@@ -566,30 +566,34 @@ int cdk_sklist_write_onepass (CDK_KEYLIST skl, CDK_STREAM outp, int sigclass);
 
 /*-- encrypt.c --*/
 int cdk_file_encrypt (CDK_HD hd, CDK_STRLIST remusr,
-                      const char *file,
-                      const char *output);
-int cdk_file_decrypt (CDK_HD hd, const char *file,
-                      const char *output);
+                      const char * file,
+                      const char * output);
+int cdk_file_decrypt (CDK_HD hd, const char * file,
+                      const char * output);
 
 /*-- verify.c --*/
-int cdk_file_verify (CDK_HD hd, const char *file);
+int cdk_file_verify (CDK_HD hd, const char * file);
 int cdk_file_verify_clearsign (CDK_HD hd, const char * file,
                                const char * output);
 
 /*-- sign.c --*/
 int cdk_file_clearsign (CDK_HD hd, CDK_STRLIST locusr,
-                        const char *file, const char * output);
+                        const char * file, const char * output);
 
 /*-- trustdb.c --*/
-int cdk_trustdb_get_validity (CDK_STREAM inp, cdkPKT_user_id *id, int *r_val);
-int cdk_trustdb_get_ownertrust (CDK_STREAM inp, cdkPKT_public_key *pk,
-                                int *r_val, int *r_flags);
+int cdk_trustdb_get_validity (CDK_STREAM inp, cdkPKT_user_id * id, int *r_val);
+int cdk_trustdb_get_ownertrust (CDK_STREAM inp, cdkPKT_public_key * pk,
+                                int * r_val, int * r_flags);
 
 /*-- misc.c --*/
 void cdk_strlist_free (CDK_STRLIST sl);
-CDK_STRLIST cdk_strlist_add (CDK_STRLIST *list, const char *string);
+CDK_STRLIST cdk_strlist_add (CDK_STRLIST * list, const char * string);
 const char * cdk_strlist_walk (CDK_STRLIST root, CDK_STRLIST * context);
-const char* cdk_check_version (const char *req_version);
+const char* cdk_check_version (const char * req_version);
+
+/*-- keyserver.c --*/
+int cdk_keyserver_recv_key (const char * host, int port,
+                            unsigned long * keyid, CDK_KBNODE * r_knode);
 
 #endif /* OPENCDK_H */
 
