@@ -1,4 +1,4 @@
-/* pubkey.c - Public key functions with S-EXP interface
+/* pubkey.c - Public key handling
  *        Copyright (C) 2002 Timo Schulz
  *
  * This file is part of OpenCDK.
@@ -60,7 +60,7 @@ static GCRY_MPI *
 bitmpi_to_gcrympi (CDK_MPI m[4], int ncount)
 {
   int i = 0, rc = 0;
-  GCRY_MPI *d = NULL;
+  GCRY_MPI * d = NULL;
   size_t nbytes = 0;
 
   if (!m)
@@ -90,7 +90,7 @@ skey_to_sexp (GCRY_SEXP * r_skey, cdkPKT_secret_key * sk)
 {
   cdkPKT_public_key *pk = NULL;
   GCRY_SEXP sexp = NULL;
-  GCRY_MPI *m_pk = NULL, *m_sk = NULL;
+  GCRY_MPI * m_pk = NULL, * m_sk = NULL;
   const char *fmt = NULL;
   int ncount = 0, nscount = 0;
   int rc = 0;
@@ -361,8 +361,8 @@ static int
 enc_to_sexp (GCRY_SEXP * r_sexp, cdkPKT_pubkey_enc * enc)
 {
   GCRY_SEXP sexp = NULL;
-  GCRY_MPI *m = NULL;
-  const char *fmt = NULL;
+  GCRY_MPI * m = NULL;
+  const char * fmt = NULL;
   int ncount;
   int rc = 0;
 
@@ -456,7 +456,7 @@ int
 cdk_pk_sign (cdkPKT_secret_key * sk, cdkPKT_signature * sig, const byte * md)
 {
   GCRY_SEXP s_skey = NULL, s_sig = NULL, s_hash = NULL;
-  byte *encmd = NULL;
+  byte * encmd = NULL;
   size_t enclen = 0;
   int nbits = 0;
   int rc = 0;
@@ -495,11 +495,10 @@ cdk_pk_sign (cdkPKT_secret_key * sk, cdkPKT_signature * sig, const byte * md)
 
 
 int
-cdk_pk_verify (cdkPKT_public_key * pk, cdkPKT_signature * sig,
-	       const byte * md)
+cdk_pk_verify (cdkPKT_public_key * pk, cdkPKT_signature * sig, const byte * md)
 {
   GCRY_SEXP s_pkey = NULL, s_sig = NULL, s_hash = NULL;
-  byte *encmd = NULL;
+  byte * encmd = NULL;
   size_t enclen = 0;
   int nbits = 0;
   int rc = 0;
@@ -664,7 +663,7 @@ checksum_mpi (CDK_MPI m)
 
 
 int
-cdk_seckey_unprotect (cdkPKT_secret_key * sk, char *pw)
+cdk_seckey_unprotect (cdkPKT_secret_key * sk, char * pw)
 {
   GCRY_CIPHER_HD hd;
   CDK_DEK dek = NULL;
@@ -672,7 +671,7 @@ cdk_seckey_unprotect (cdkPKT_secret_key * sk, char *pw)
   u16 chksum = 0;
   size_t ndata;
   int j, i, dlen, pos = 0, nskey;
-  byte *data = NULL;
+  byte * data = NULL;
 
   if (!sk)
     return CDK_Inv_Value;
