@@ -159,8 +159,8 @@ read_mpi (CDK_STREAM inp, CDK_MPI * ret_m, int secure)
 
   nbits = read_16 (inp, &rc);
   nbytes = (nbits + 7) / 8;
-  if (rc || nbits > MAX_MPI_BITS || nbits == 0)
-    return CDK_MPI_Error;		/* sanity check */
+  if (nbits > MAX_MPI_BITS || nbits == 0)
+    return CDK_MPI_Error; /* sanity check */
   if (secure)
     m = cdk_scalloc (sizeof *m + nbytes + 2);
   else
@@ -722,6 +722,9 @@ read_signature (CDK_STREAM inp, cdkPKT_signature * sig)
   if (sig->version < 2 || sig->version > 4)
       return CDK_Inv_Packet_Ver;
 
+  sig->flags.exportable = 1;
+  sig->flags.revocable = 1;
+  
   if (sig->version < 4)
     {
       if (stream_getc (inp) != 5)
@@ -768,9 +771,7 @@ read_signature (CDK_STREAM inp, cdkPKT_signature * sig)
             break;
           size -= nbytes;
 	}
-      
-      sig->flags.exportable = 1;
-      sig->flags.revocable = 1;
+
       /* Setup the standard packet entries, so we can use V4
          signatures similar to V3. */
       for (p = sig->unhashed; p; p = p->next)
@@ -786,7 +787,7 @@ read_signature (CDK_STREAM inp, cdkPKT_signature * sig)
 	      sig->flags.exportable = 0;
 	    }
 	}
-      for (p = sig->hashed; p && p->size; p = p->next)
+      for (p = sig->hashed; p; p = p->next)
 	{
 	  if (p->type == SIGSUBPKT_SIG_CREATED)
 	    sig->timestamp = buffer_to_u32 (p->d);
