@@ -348,7 +348,7 @@ write_signature (CDK_STREAM out, cdkPKT_signature * sig)
 	rc = stream_putc (out, 3);
       if (!rc)
 	rc = stream_putc (out, 5);
-      if (rc)
+      if (!rc)
 	rc = stream_putc (out, sig->sig_class);
       if (!rc)
 	rc = write_32 (out, sig->timestamp);
@@ -417,10 +417,10 @@ write_signature (CDK_STREAM out, cdkPKT_signature * sig)
 
 
 static int
-write_public_key (CDK_STREAM out, cdkPKT_public_key * pk)
+write_public_key (CDK_STREAM out, cdkPKT_public_key * pk, int is_subkey)
 {
   int rc = 0;
-  int i, size = 6;
+  int i, size = 6, pkttype;
   size_t npkey = 0;
 
   if (!out || !pk)
@@ -432,11 +432,12 @@ write_public_key (CDK_STREAM out, cdkPKT_public_key * pk)
   if (DEBUG_PKT)
     _cdk_log_debug ("** write public key packet\n");
 
+  pkttype = is_subkey? CDK_PKT_PUBLIC_SUBKEY : CDK_PKT_PUBLIC_KEY;
   npkey = cdk_pk_get_npkey (pk->pubkey_algo);
   if (pk->version < 4)
-    size += 2;			/* expire date */
+    size += 2; /* expire date */
   size += calc_mpi_size (pk->mpi, npkey);
-  rc = pkt_write_head (out, size, CDK_PKT_PUBLIC_KEY);
+  rc = pkt_write_head (out, size, pkttype);
   if (!rc)
     rc = stream_putc (out, pk->version);
   if (!rc)
@@ -680,10 +681,10 @@ cdk_pkt_build (CDK_STREAM out, CDK_PACKET * pkt)
       rc = write_signature (out, pkt->pkt.signature);
       break;
     case CDK_PKT_PUBLIC_KEY:
-      rc = write_public_key (out, pkt->pkt.public_key);
+      rc = write_public_key (out, pkt->pkt.public_key, 0);
       break;
     case CDK_PKT_PUBLIC_SUBKEY:
-      rc = write_public_key (out, pkt->pkt.public_key);
+      rc = write_public_key (out, pkt->pkt.public_key, 1);
       break;
     case CDK_PKT_COMPRESSED:
       rc = write_compressed (out, pkt->pkt.compressed);
